package es.uca.xmleye.util;

/*
  Copyright (C) 2008 Antonio García Domínguez

  This program is free software; you can redistribute it
  and/or modify it under the terms of the GNU General Public
  License as published by the Free Software Foundation;
  either version 2 of the License, or (at your option) any
  later version.

  This program is distributed in the hope that it will be
  useful, but WITHOUT ANY WARRANTY; without even the implied
  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE. See the GNU General Public License for more
  details.

  You should have received a copy of the GNU General Public
  License along with this program; if not, write to the Free
  Software Foundation, Inc., 59 Temple Place, Suite 330,
  Boston, MA 02111-1307 USA
*/

import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;

/**
 * Background task which reads lines of text from an input stream and
 * dispatches them to several {@link LineFilter}s.
 *
 * @author Antonio García Domínguez
 * @version 1.0
 */
public class LineDemuxTask implements InputTask {

  private BufferedReader is;
  private LineFilter[] filters;

  public LineDemuxTask(LineFilter[] filters) {
    this.filters = filters;
  }

  public void setInputStream(InputStream in) {
    this.is = new BufferedReader(new InputStreamReader(in));
  }

  public Integer call() throws Exception {
    int nLines = 0;
    String line;
    while ((line = is.readLine()) != null) {
      for (LineFilter f : filters) {
        f.processLine(line);
      }
      ++nLines;
    }
    for (LineFilter f : filters) {
      f.eofReached();
    }
    is.close();
    return nLines;
  }
}
